@@ -7,6 +7,7 @@ PROJECT_NAME = None
 
 __all__ = ["set_project_name", "add_log_file"]
 
+FORMAT="%(asctime)s - %(filename)12s:%(lineno)4d - %(threadName)10s[%(levelname)7s]:%(message)s"
 
 def set_project_name(project_name: str, force: bool = False):
     global PROJECT_NAME
@@ -41,8 +42,10 @@ def add_log_file(log_file: str, project_name: str = None):
         log_path = pathlib.Path(log_dir)
         log_path.mkdir(parents=True, exist_ok=True)
         log_path /= log_file
+        formatter = logging.Formatter(FORMAT)
         handler = logging.FileHandler(log_path)
-        logging.addHandler(handler)
+        handler.setFormatter(formatter)
+        logging.getLogger().addHandler(handler)
         logging.debug("Added File Handler %r", handler)
     else:
         logging.debug("No Filehandler added")
